CreatePayment class

Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake, includeIfNull: false)

Constructors

CreatePayment({required String currency, required String beneficiaryId, required Decimal amount, required String reason, required String reference, String? paymentDate, PaymentType? paymentType = PaymentType.regular, String? conversionId, EntityType? payerEntityType, String? payerCompanyName, String? payerFirstName, String? payerLastName, String? payerCity, String? payerAddress, String? payerPostcode, String? payerStateOrProvince, String? payerCountry, String? payerDateOfBirth, IdentificationType? payerIdentificationType, String? payerIdentificationValue, String? uniqueRequestId, String? ultimateBeneficiaryName, String? onBehalfOf})
CreatePayment.fromJson(Map<String, dynamic> json)
factory

Properties

amount → Decimal
final
beneficiaryId → String
final
conversionId → String?
final
currency → String
final
hashCode → int
The hash code for this object.
no setterinherited
onBehalfOf → String?
final
payerAddress → String?
final
payerCity → String?
final
payerCompanyName → String?
final
payerCountry → String?
final
payerDateOfBirth → String?
final
payerEntityType → EntityType?
final
payerFirstName → String?
final
payerIdentificationType → IdentificationType?
final
payerIdentificationValue → String?
final
payerLastName → String?
final
payerPostcode → String?
final
payerStateOrProvince → String?
final
paymentDate → String?
final
paymentType → PaymentType?
final
reason → String
final
reference → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
ultimateBeneficiaryName → String?
final
uniqueRequestId → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited