Rate class

Annotations
  • @JsonSerializable.new(fieldRename: FieldRename.snake, includeIfNull: false)

Constructors

Rate()
Rate.fromJson(Map<String, dynamic> json)
factory

Properties

clientBuyAmount ↔ Decimal?
getter/setter pair
clientBuyCurrency ↔ String?
Currency code (ISO 4217)
getter/setter pair
clientRate ↔ Decimal?
getter/setter pair
clientSellAmount ↔ Decimal?
getter/setter pair
clientSellCurrency ↔ String?
Currency code (ISO 4217)
getter/setter pair
coreRate ↔ Decimal?
getter/setter pair
currencyPair ↔ String?
getter/setter pair
depositAmount ↔ Decimal?
getter/setter pair
depositCurrency ↔ String?
Currency code (ISO 4217)
getter/setter pair
depositRequired ↔ bool?
getter/setter pair
fixedSide ↔ FixedSide?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
midMarketRate ↔ Decimal?
getter/setter pair
partnerRate ↔ Decimal?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
settlementCutOffTime ↔ DateTime?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited